@@ -23,8 +23,12 @@ sub get_methods_for {
 
     return
         sort { $a->{name} cmp $b->{name} }
-        grep { blessed $_ && $_->isa('Net::Twitter::Meta::Method') }
-             $nt->meta->get_all_methods;
+        grep {
+            $_->isa('Net::Twitter::Meta::Method')
+        }
+        map {
+            $_->isa('Class::MOP::Method::Wrapped') ? $_->get_original_method : $_
+        } $nt->meta->get_all_methods;
 } 
 
 sub get_base_url_for {
